CycleId

Struct CycleId 

pub struct CycleId(/* private fields */);
Numeric identifier of a control cycle

Periodic control cycles are usually distinguished by their frequency. This identifier allows to reference control cycles independent of their actual properties.

Implementations

Source

impl CycleId

pub const fn from_value(value: CycleIdValue) -> Self

pub const fn to_value(self) -> CycleIdValue