pub struct RollingFileSystem {
pub base_path: PathBuf,
pub file_name_template: RollingFileNameTemplate,
}Fields
base_path: PathBuffile_name_template: RollingFileNameTemplateImplementations
Sourceimpl RollingFileSystem
impl RollingFileSystem
pub fn new_file_path(&self, created_at: FileNameTimeStamp) -> PathBuf
pub fn open_new_file_for_writing( &self, created_at: FileNameTimeStamp, ) -> IoResult<OpenRollingFile>
Sourcepub fn read_all_dir_entries_filtered(
&self,
filter: &FileInfoFilter,
) -> IoResult<Vec<RollingFileInfoWithSize>>
pub fn read_all_dir_entries_filtered( &self, filter: &FileInfoFilter, ) -> IoResult<Vec<RollingFileInfoWithSize>>
Read all entries in the base path directory
The matching entries are returned in no particular order.
Sourcepub fn read_all_dir_entries_filtered_chronologically(
&self,
filter: &FileInfoFilter,
) -> IoResult<Vec<RollingFileInfoWithSize>>
pub fn read_all_dir_entries_filtered_chronologically( &self, filter: &FileInfoFilter, ) -> IoResult<Vec<RollingFileInfoWithSize>>
Read all entries in the base path directory, sorted by created at in ascending order
pub fn read_most_recent_dir_entry( &self, ) -> IoResult<Option<RollingFileInfoWithSize>>