Timestamp

Struct Timestamp 

pub struct Timestamp(/* private fields */);
A timestamp

Implementations

Source

impl Timestamp

pub const fn new(inner: OffsetDateTime) -> Self

pub const fn to_inner(self) -> OffsetDateTime

pub const fn to_utc(self) -> Self

pub fn now() -> Self

Current system time with offset

Tries to obtain the current system time with the local time zone offset. Returns an UTC timestamp as a fallback if the local time zone is unknown or could not be determined.

Prefer to use Self::now_utc() if the local time zone offset doesn’t matter.

pub fn now_utc() -> Self

Current system time (UTC)

pub fn parse_rfc3339(input: &str) -> Result<Self, Parse>

pub fn format_rfc3339(&self) -> Result<String, Format>

pub fn format_rfc3339_into<W: Write>( &self, output: &mut W, ) -> Result<usize, Format>

Methods from Deref<Target = OffsetDateTime>