pub struct CycleId(/* private fields */);Expand description
Numeric identifier of a control cycle
Periodic control cycles are usually distinguished by their frequency. This identifier allows to reference control cycles independent of their actual properties.
Implementations
Sourceimpl CycleId
impl CycleId
pub const fn from_value(value: CycleIdValue) -> Self
pub const fn to_value(self) -> CycleIdValue